@@ -23,16 +23,23 @@
 #define __SWFDEC_H__
 
 #include <libswfdec/swfdec_as_context.h>
+#include <libswfdec/swfdec_as_debugger.h>
 #include <libswfdec/swfdec_as_frame.h>
+#include <libswfdec/swfdec_as_function.h>
+#include <libswfdec/swfdec_as_native_function.h>
 #include <libswfdec/swfdec_as_object.h>
 #include <libswfdec/swfdec_as_types.h>
+#include <libswfdec/swfdec_script.h>
 
 #include <libswfdec/swfdec_audio.h>
 #include <libswfdec/swfdec_buffer.h>
 #include <libswfdec/swfdec_enums.h>
 #include <libswfdec/swfdec_file_loader.h>
+#include <libswfdec/swfdec_keys.h>
 #include <libswfdec/swfdec_loader.h>
 #include <libswfdec/swfdec_player.h>
+#include <libswfdec/swfdec_rectangle.h>
+#include <libswfdec/swfdec_system.h>
 #include <libswfdec/swfdec_url.h>
 
 #endif
