@@ -213,6 +213,22 @@ swfdec_as_object_hash_create (SwfdecAsObject *object, const char *variable, guin
   return var;
 }
 
+static gboolean
+swfdec_as_object_variable_enabled_in_version (SwfdecAsVariable *var,
+    guint version)
+{
+  if (var->flags & SWFDEC_AS_VARIABLE_VERSION_6_UP && version < 6)
+    return FALSE;
+  if (var->flags & SWFDEC_AS_VARIABLE_VERSION_NOT_6 && version == 6)
+    return FALSE;
+  if (var->flags & SWFDEC_AS_VARIABLE_VERSION_7_UP && version < 7)
+    return FALSE;
+  if (var->flags & SWFDEC_AS_VARIABLE_VERSION_8_UP && version < 8)
+    return FALSE;
+
+  return TRUE;
+}
+
 static gboolean
 swfdec_as_object_do_get (SwfdecAsObject *object, SwfdecAsObject *orig,
     const char *variable, SwfdecAsValue *val, guint *flags)
@@ -223,13 +239,8 @@ swfdec_as_object_do_get (SwfdecAsObject *object, SwfdecAsObject *orig,
     return FALSE;
 
   /* variable flag checks */
-  if (var->flags & SWFDEC_AS_VARIABLE_VERSION_6_UP && object->context->version < 6)
-    return FALSE;
-  if (var->flags & SWFDEC_AS_VARIABLE_VERSION_NOT_6 && object->context->version == 6)
-    return FALSE;
-  if (var->flags & SWFDEC_AS_VARIABLE_VERSION_7_UP && object->context->version < 7)
-    return FALSE;
-  if (var->flags & SWFDEC_AS_VARIABLE_VERSION_8_UP && object->context->version < 8)
+  if (!swfdec_as_object_variable_enabled_in_version (var,
+	object->context->version))
     return FALSE;
 
   if (var->get) {
@@ -355,32 +366,40 @@ swfdec_as_object_get_prototype (SwfdecAsObject *object)
 
 static SwfdecAsVariable *
 swfdec_as_object_hash_lookup_with_prototype (SwfdecAsObject *object,
-    const char *variable)
+    const char *variable, SwfdecAsObject **proto)
 {
   SwfdecAsVariable *var;
+  SwfdecAsObject *proto_;
 
   g_return_val_if_fail (swfdec_as_variable_name_is_valid (variable), NULL);
 
+  proto_ = NULL;
+
+  // match first level variable even if it has version flags that hide it in
+  // this version
   var = swfdec_as_object_hash_lookup (object, variable);
   if (var == NULL && variable != SWFDEC_AS_STR___proto__) {
     guint i;
-    SwfdecAsObject *proto;
 
-    proto = swfdec_as_object_get_prototype (object);
+    proto_ = swfdec_as_object_get_prototype (object);
 
-    for (i = 0; i < SWFDEC_AS_OBJECT_PROTOTYPE_RECURSION_LIMIT && proto; i++) {
-      var = swfdec_as_object_hash_lookup (proto, variable);
+    for (i = 0; i < SWFDEC_AS_OBJECT_PROTOTYPE_RECURSION_LIMIT && proto_; i++) {
+      var = swfdec_as_object_hash_lookup (proto_, variable);
       if (var && var->get)
 	break;
-      proto = swfdec_as_object_get_prototype (proto);
+      proto_ = swfdec_as_object_get_prototype (proto_);
       var = NULL;
     }
+
     if (i == SWFDEC_AS_OBJECT_PROTOTYPE_RECURSION_LIMIT) {
       swfdec_as_context_abort (object->context, "Prototype recursion limit exceeded");
       return NULL;
     }
   }
 
+  if (proto != NULL)
+    *proto = proto_;
+
   return var;
 }
 
@@ -390,14 +409,28 @@ swfdec_as_object_do_set (SwfdecAsObject *object, const char *variable,
 {
   SwfdecAsVariable *var;
   SwfdecAsWatch *watch;
+  SwfdecAsObject *proto;
 
   if (!swfdec_as_variable_name_is_valid (variable))
     return;
 
-  var = swfdec_as_object_hash_lookup_with_prototype (object, variable);
+  var = swfdec_as_object_hash_lookup_with_prototype (object, variable, &proto);
   if (swfdec_as_context_is_aborted (object->context))
     return;
 
+  // if variable is disabled in this version
+  if (var != NULL && !swfdec_as_object_variable_enabled_in_version (var,
+	object->context->version)) {
+    if (proto == NULL) {
+      // it's at the top level, remove getter and setter plus overwrite
+      var->get = NULL;
+      var->set = NULL;
+    } else {
+      // it's in proto, we create a new one at the top level
+      var = NULL;
+    }
+  }
+
   if (var == NULL) {
     var = swfdec_as_object_hash_create (object, variable, flags);
     if (var == NULL)
@@ -432,7 +465,8 @@ swfdec_as_object_do_set (SwfdecAsObject *object, const char *variable,
       swfdec_as_function_call (watch->watch, object, 4, args, &ret);
       swfdec_as_context_run (object->context);
       swfdec_as_watch_unref (watch);
-      var = swfdec_as_object_hash_lookup_with_prototype (object, variable);
+      var = swfdec_as_object_hash_lookup_with_prototype (object, variable,
+	  NULL);
       if (swfdec_as_context_is_aborted (object->context))
 	return;
       if (var == NULL) {
@@ -897,6 +931,36 @@ swfdec_as_object_get_variable_and_flags (SwfdecAsObject *object,
   return FALSE;
 }
 
+/**
+ * swfdec_as_object_has_variable:
+ * @object: a #SwfdecAsObject
+ * @variable: garbage-collected variable name
+ *
+ * Checks if a user-set @variable with the given name exists on @object. This 
+ * function does not check variables that are available via an overwritten get 
+ * function of the object's class.
+ *
+ * Returns: %TRUE if the @object contains the given @variable
+ **/
+gboolean
+swfdec_as_object_has_variable (SwfdecAsObject *object, const char *variable)
+{
+  guint i;
+  SwfdecAsVariable *var;
+
+  g_return_val_if_fail (SWFDEC_IS_AS_OBJECT (object), FALSE);
+  
+  for (i = 0; i <= SWFDEC_AS_OBJECT_PROTOTYPE_RECURSION_LIMIT && object != NULL; i++) {
+    var = swfdec_as_object_hash_lookup (object, variable);
+    if (var) {
+      /* FIXME: propflags? */
+      return TRUE;
+    }
+    object = swfdec_as_object_get_prototype_internal (object);
+  }
+  return FALSE;
+}
+
 /**
  * swfdec_as_object_delete_variable:
  * @object: a #SwfdecAsObject
@@ -905,7 +969,7 @@ swfdec_as_object_get_variable_and_flags (SwfdecAsObject *object,
  * Deletes the given variable if possible. If the variable is protected from 
  * deletion, it will not be deleted.
  *
- * Returns: See #SwfdecAsDeleteReutnr for details of the return value.
+ * Returns: See #SwfdecAsDeleteReturn for details of the return value.
  **/
 SwfdecAsDeleteReturn
 swfdec_as_object_delete_variable (SwfdecAsObject *object, const char *variable)
@@ -1185,30 +1249,6 @@ swfdec_as_object_call (SwfdecAsObject *object, const char *name, guint argc,
   g_object_unref (sec);
 }
 
-/**
- * swfdec_as_object_has_function:
- * @object: a #SwfdecAsObject
- * @name: garbage-collected name of th function
- *
- * Convenience function that checks of @object has a variable that references 
- * a function.
- *
- * Returns: %TRUE if object.name is a function.
- **/
-gboolean
-swfdec_as_object_has_function (SwfdecAsObject *object, const char *name)
-{
-  SwfdecAsValue val;
-
-  g_return_val_if_fail (SWFDEC_IS_AS_OBJECT (object), FALSE);
-  g_return_val_if_fail (name != NULL, FALSE);
-
-  swfdec_as_object_get_variable (object, name, &val);
-  if (!SWFDEC_AS_VALUE_IS_OBJECT (&val))
-    return FALSE;
-  return SWFDEC_IS_AS_FUNCTION (SWFDEC_AS_VALUE_GET_OBJECT (&val));
-}
-
 /**
  * swfdec_as_object_create:
  * @fun: constructor
@@ -1609,6 +1649,9 @@ swfdec_as_object_decode (SwfdecAsObject *object, const char *str)
   char **varlist, *p, *unescaped;
   guint i;
 
+  g_return_if_fail (SWFDEC_IS_AS_OBJECT (object));
+  g_return_if_fail (str != NULL);
+
   varlist = g_strsplit (str, "&", -1);
 
   for (i = 0; varlist[i] != NULL; i++) {
