@@ -143,6 +143,8 @@ gboolean	swfdec_as_object_get_variable_and_flags
 						 SwfdecAsValue *	value,
 						 guint *		flags,
 						 SwfdecAsObject **	pobject);
+gboolean	swfdec_as_object_has_variable	(SwfdecAsObject *	object,
+						 const char *		variable);
 SwfdecAsDeleteReturn
 		swfdec_as_object_delete_variable(SwfdecAsObject *	object,
 						 const char *		variable);
@@ -174,8 +176,6 @@ SwfdecAsFunction *swfdec_as_object_add_constructor
 						 guint			min_args,
 						 SwfdecAsObject *	prototype);
 
-gboolean	swfdec_as_object_has_function	(SwfdecAsObject *       object,
-						 const char *		name);
 void		swfdec_as_object_call		(SwfdecAsObject *       object,
 						 const char *		name,
 						 guint			argc,
