@@ -432,5 +432,56 @@ const char swfdec_as_strings[] =
   SWFDEC_AS_CONSTANT_STRING ("URLNotFound")
   SWFDEC_AS_CONSTANT_STRING ("IllegalRequest")
   SWFDEC_AS_CONSTANT_STRING ("LoadNeverCompleted")
+  SWFDEC_AS_CONSTANT_STRING ("creationDate")
+  SWFDEC_AS_CONSTANT_STRING ("creator")
+  SWFDEC_AS_CONSTANT_STRING ("modificationDate")
+  SWFDEC_AS_CONSTANT_STRING ("name")
+  SWFDEC_AS_CONSTANT_STRING ("postData")
+  SWFDEC_AS_CONSTANT_STRING ("PrintJob")
+  SWFDEC_AS_CONSTANT_STRING ("orientation")
+  SWFDEC_AS_CONSTANT_STRING ("pageHeight")
+  SWFDEC_AS_CONSTANT_STRING ("pageWidth")
+  SWFDEC_AS_CONSTANT_STRING ("paperHeight")
+  SWFDEC_AS_CONSTANT_STRING ("paperWidth")
+  SWFDEC_AS_CONSTANT_STRING ("callee")
+  SWFDEC_AS_CONSTANT_STRING ("caller")
+  SWFDEC_AS_CONSTANT_STRING ("enableDebugConsole")
+  SWFDEC_AS_CONSTANT_STRING ("remote")
+  SWFDEC_AS_CONSTANT_STRING ("localWithFile")
+  SWFDEC_AS_CONSTANT_STRING ("localWithNetwork")
+  SWFDEC_AS_CONSTANT_STRING ("localTrusted")
+  SWFDEC_AS_CONSTANT_STRING ("normal")
+  SWFDEC_AS_CONSTANT_STRING ("layer")
+  SWFDEC_AS_CONSTANT_STRING ("multiply")
+  SWFDEC_AS_CONSTANT_STRING ("screen")
+  SWFDEC_AS_CONSTANT_STRING ("lighten")
+  SWFDEC_AS_CONSTANT_STRING ("darken")
+  SWFDEC_AS_CONSTANT_STRING ("difference")
+  SWFDEC_AS_CONSTANT_STRING ("add")
+  SWFDEC_AS_CONSTANT_STRING ("subtract")
+  SWFDEC_AS_CONSTANT_STRING ("invert")
+  SWFDEC_AS_CONSTANT_STRING ("alpha")
+  SWFDEC_AS_CONSTANT_STRING ("erase")
+  SWFDEC_AS_CONSTANT_STRING ("overlay")
+  SWFDEC_AS_CONSTANT_STRING ("hardlight")
+  SWFDEC_AS_CONSTANT_STRING ("getTextExtent")
+  SWFDEC_AS_CONSTANT_STRING ("domain")
+  SWFDEC_AS_CONSTANT_STRING ("linear")
+  SWFDEC_AS_CONSTANT_STRING ("radial")
+  SWFDEC_AS_CONSTANT_STRING ("matrixType")
+  SWFDEC_AS_CONSTANT_STRING ("box")
+  SWFDEC_AS_CONSTANT_STRING ("a")
+  SWFDEC_AS_CONSTANT_STRING ("b")
+  SWFDEC_AS_CONSTANT_STRING ("c")
+  SWFDEC_AS_CONSTANT_STRING ("d")
+  SWFDEC_AS_CONSTANT_STRING ("e")
+  SWFDEC_AS_CONSTANT_STRING ("f")
+  SWFDEC_AS_CONSTANT_STRING ("g")
+  SWFDEC_AS_CONSTANT_STRING ("h")
+  SWFDEC_AS_CONSTANT_STRING ("i")
+  SWFDEC_AS_CONSTANT_STRING ("r")
+  SWFDEC_AS_CONSTANT_STRING ("w")
+  SWFDEC_AS_CONSTANT_STRING ("x")
+  SWFDEC_AS_CONSTANT_STRING ("y")
   /* add more here */
 ;
