@@ -413,5 +413,56 @@ extern const char swfdec_as_strings[];
 #define SWFDEC_AS_STR_URLNotFound &swfdec_as_strings[4383]
 #define SWFDEC_AS_STR_IllegalRequest &swfdec_as_strings[4396]
 #define SWFDEC_AS_STR_LoadNeverCompleted &swfdec_as_strings[4412]
+#define SWFDEC_AS_STR_creationDate &swfdec_as_strings[4432]
+#define SWFDEC_AS_STR_creator &swfdec_as_strings[4446]
+#define SWFDEC_AS_STR_modificationDate &swfdec_as_strings[4455]
+#define SWFDEC_AS_STR_name &swfdec_as_strings[4473]
+#define SWFDEC_AS_STR_postData &swfdec_as_strings[4479]
+#define SWFDEC_AS_STR_PrintJob &swfdec_as_strings[4489]
+#define SWFDEC_AS_STR_orientation &swfdec_as_strings[4499]
+#define SWFDEC_AS_STR_pageHeight &swfdec_as_strings[4512]
+#define SWFDEC_AS_STR_pageWidth &swfdec_as_strings[4524]
+#define SWFDEC_AS_STR_paperHeight &swfdec_as_strings[4535]
+#define SWFDEC_AS_STR_paperWidth &swfdec_as_strings[4548]
+#define SWFDEC_AS_STR_callee &swfdec_as_strings[4560]
+#define SWFDEC_AS_STR_caller &swfdec_as_strings[4568]
+#define SWFDEC_AS_STR_enableDebugConsole &swfdec_as_strings[4576]
+#define SWFDEC_AS_STR_remote &swfdec_as_strings[4596]
+#define SWFDEC_AS_STR_localWithFile &swfdec_as_strings[4604]
+#define SWFDEC_AS_STR_localWithNetwork &swfdec_as_strings[4619]
+#define SWFDEC_AS_STR_localTrusted &swfdec_as_strings[4637]
+#define SWFDEC_AS_STR_normal &swfdec_as_strings[4651]
+#define SWFDEC_AS_STR_layer &swfdec_as_strings[4659]
+#define SWFDEC_AS_STR_multiply &swfdec_as_strings[4666]
+#define SWFDEC_AS_STR_screen &swfdec_as_strings[4676]
+#define SWFDEC_AS_STR_lighten &swfdec_as_strings[4684]
+#define SWFDEC_AS_STR_darken &swfdec_as_strings[4693]
+#define SWFDEC_AS_STR_difference &swfdec_as_strings[4701]
+#define SWFDEC_AS_STR_add &swfdec_as_strings[4713]
+#define SWFDEC_AS_STR_subtract &swfdec_as_strings[4718]
+#define SWFDEC_AS_STR_invert &swfdec_as_strings[4728]
+#define SWFDEC_AS_STR_alpha &swfdec_as_strings[4736]
+#define SWFDEC_AS_STR_erase &swfdec_as_strings[4743]
+#define SWFDEC_AS_STR_overlay &swfdec_as_strings[4750]
+#define SWFDEC_AS_STR_hardlight &swfdec_as_strings[4759]
+#define SWFDEC_AS_STR_getTextExtent &swfdec_as_strings[4770]
+#define SWFDEC_AS_STR_domain &swfdec_as_strings[4785]
+#define SWFDEC_AS_STR_linear &swfdec_as_strings[4793]
+#define SWFDEC_AS_STR_radial &swfdec_as_strings[4801]
+#define SWFDEC_AS_STR_matrixType &swfdec_as_strings[4809]
+#define SWFDEC_AS_STR_box &swfdec_as_strings[4821]
+#define SWFDEC_AS_STR_a &swfdec_as_strings[4826]
+#define SWFDEC_AS_STR_b &swfdec_as_strings[4829]
+#define SWFDEC_AS_STR_c &swfdec_as_strings[4832]
+#define SWFDEC_AS_STR_d &swfdec_as_strings[4835]
+#define SWFDEC_AS_STR_e &swfdec_as_strings[4838]
+#define SWFDEC_AS_STR_f &swfdec_as_strings[4841]
+#define SWFDEC_AS_STR_g &swfdec_as_strings[4844]
+#define SWFDEC_AS_STR_h &swfdec_as_strings[4847]
+#define SWFDEC_AS_STR_i &swfdec_as_strings[4850]
+#define SWFDEC_AS_STR_r &swfdec_as_strings[4853]
+#define SWFDEC_AS_STR_w &swfdec_as_strings[4856]
+#define SWFDEC_AS_STR_x &swfdec_as_strings[4859]
+#define SWFDEC_AS_STR_y &swfdec_as_strings[4862]
 
 #endif
