@@ -232,7 +232,6 @@ swfdec_flv_decoder_find_data (SwfdecFlvDecoder *flv, guint timestamp)
 static SwfdecStatus
 swfdec_flv_decoder_parse_video_tag (SwfdecFlvDecoder *flv, SwfdecBits *bits, guint timestamp)
 {
-  SwfdecDecoder *dec = SWFDEC_DECODER (flv);
   SwfdecFlvVideoTag tag;
 
   if (flv->video == NULL) {
@@ -264,26 +263,7 @@ swfdec_flv_decoder_parse_video_tag (SwfdecFlvDecoder *flv, SwfdecBits *bits, gui
     idx = swfdec_flv_decoder_find_video (flv, tag.timestamp);
     g_array_insert_val (flv->video, idx, tag);
   }
-  if (dec->width == 0 && dec->height == 0) {
-    SwfdecFlvVideoTag *t = &g_array_index (flv->video, SwfdecFlvVideoTag, 0);
-    SwfdecVideoDecoder *decoder;
-    cairo_surface_t *surface;
-
-    /* nice hack... */
-    decoder = swfdec_video_decoder_new (t->format);
-    if (decoder == NULL)
-      return SWFDEC_STATUS_OK;
-    surface = swfdec_video_decoder_decode (decoder, t->buffer);
-    if (surface == NULL)
-      return SWFDEC_STATUS_OK;
-    dec->width = cairo_image_surface_get_width (surface);
-    dec->height = cairo_image_surface_get_height (surface);
-    swfdec_video_decoder_free (decoder);
-    cairo_surface_destroy (surface);
-    return SWFDEC_STATUS_INIT;
-  } else {
-    return SWFDEC_STATUS_IMAGE;
-  }
+  return SWFDEC_STATUS_IMAGE;
 }
 
 static void
