@@ -451,18 +451,21 @@ swfdec_image_lossless_load (SwfdecImage *image)
   } else if (format == 5) {
     SwfdecBuffer *buffer;
     int i, j;
+    guint32 *p;
+
     buffer = swfdec_bits_decompress (&bits, -1, 4 * image->width * image->height);
     if (buffer == NULL) {
       SWFDEC_ERROR ("failed to decompress data");
       data = g_malloc0 (4 * image->width * image->height);
       goto out;
     }
-    ptr = data = buffer->data;
+    data = buffer->data;
+    p = (void *) data;
     /* image is stored in 0RGB format.  We use ARGB/BGRA. */
     for (j = 0; j < image->height; j++) {
       for (i = 0; i < image->width; i++) {
-	*((guint32 *) ptr) = GUINT32_FROM_BE (*((guint32 *) ptr));
-	ptr += 4;
+	*p = GUINT32_FROM_BE (*p);
+	p++;
       }
     }
     /* FIXME: this can fail if the returned buffer does not contain malloc'd 
@@ -582,6 +585,10 @@ swfdec_image_png_load (SwfdecImage *image)
   swfdec_bits_init (&bits, image->raw_data);
   image->surface = cairo_image_surface_create_from_png_stream (
       swfdec_image_png_read, &bits);
+  image->width = cairo_image_surface_get_width (image->surface);
+  image->height = cairo_image_surface_get_height (image->surface);
+  swfdec_cached_load (SWFDEC_CACHED (image), image->height *
+      cairo_image_surface_get_stride (image->surface));
 }
 
 cairo_surface_t *
@@ -629,8 +636,8 @@ cairo_surface_t *
 swfdec_image_create_surface_transformed (SwfdecImage *image, const SwfdecColorTransform *trans)
 {
   cairo_surface_t *surface, *source;
-  guint8 *tdata;
-  const guint8 *sdata;
+  guint32 *tdata;
+  const guint32 *sdata;
   guint i, n;
   gboolean has_alpha = FALSE;
 
@@ -649,15 +656,16 @@ swfdec_image_create_surface_transformed (SwfdecImage *image, const SwfdecColorTr
     return NULL;
   }
   /* FIXME: This code assumes a rowstride of 4 * width */
-  sdata = cairo_image_surface_get_data (source);
+  /* FIXME: This code assumes an alignment of 4 */
+  sdata = (void *) cairo_image_surface_get_data (source);
   n = image->width * image->height;
   for (i = 0; i < n; i++) {
-    ((guint32 *) tdata)[i] = swfdec_color_apply_transform_premultiplied (((guint32 *) sdata)[i], trans);
+    tdata[i] = swfdec_color_apply_transform_premultiplied (sdata[i], trans);
     /* optimization: check for alpha channel to speed up compositing */
-    has_alpha = tdata[4 * i + SWFDEC_COLOR_INDEX_ALPHA] != 0xFF;
+    has_alpha |= SWFDEC_COLOR_A (tdata[i]) != 0xFF;
   }
   cairo_surface_destroy (source);
-  surface = cairo_image_surface_create_for_data (tdata,
+  surface = cairo_image_surface_create_for_data ((unsigned char *) tdata,
       has_alpha ? CAIRO_FORMAT_ARGB32 : CAIRO_FORMAT_RGB24, 
       image->width, image->height, image->width * 4);
   cairo_surface_set_user_data (surface, &key, tdata, g_free);
@@ -672,7 +680,7 @@ swfdec_image_detect (const guint8 *data)
 
   if (data[0] == 0xFF && data[1] == 0xD8)
     return SWFDEC_IMAGE_TYPE_JPEG2;
-  else if (data[0] == 89 && data[1] == 'P' &&
+  else if (data[0] == 0x89 && data[1] == 'P' &&
       data[2] == 'N' && data[3] == 'G')
     return SWFDEC_IMAGE_TYPE_PNG;
   else
