@@ -31,7 +31,9 @@ typedef enum {
   SWFDEC_LOADER_DATA_SWF,
   SWFDEC_LOADER_DATA_FLV,
   SWFDEC_LOADER_DATA_XML,
-  SWFDEC_LOADER_DATA_TEXT
+  SWFDEC_LOADER_DATA_TEXT,
+  SWFDEC_LOADER_DATA_JPEG,
+  SWFDEC_LOADER_DATA_PNG
 } SwfdecLoaderDataType;
 
 /* NB: actal numbers in SwfdecLoaderRequest are important for GetURL2 action */
@@ -57,8 +59,10 @@ struct _SwfdecLoader
 
   /*< private >*/
   guint			state;		/* SwfdecLoaderState the loader is currently in */
+  guint			processed_state;/* SwfdecLoaderState the target knows about */
+  gboolean		queued;		/* TRUE if we have queued an action already */
   SwfdecURL *		url;		/* the URL for this loader in UTF-8 - must be set on creation */
-  gulong		size;		/* number of bytes in stream or 0 if unknown */
+  glong			size;		/* number of bytes in stream or -1 if unknown */
   char *		error;		/* error message if in error state or NULL */
   gpointer		target;		/* SwfdecLoaderTarget that gets notified about loading progress */
   gpointer		player;		/* SwfdecPlayer belonging to target or %NULL */
@@ -76,6 +80,8 @@ struct _SwfdecLoaderClass
 					 SwfdecLoaderRequest		request,
 					 const char *			data,
 					 gsize				data_len);
+  /* if open, close the loader. NB: you may not call push() or eof() after the loader has been closed */
+  void			(* close)	(SwfdecLoader *			loader);
 };
 
 GType		swfdec_loader_get_type		(void);
@@ -91,7 +97,7 @@ const SwfdecURL *
 		swfdec_loader_get_url		(SwfdecLoader *		loader);
 void		swfdec_loader_set_size		(SwfdecLoader *		loader,
 						 gulong			size);
-gulong		swfdec_loader_get_size		(SwfdecLoader *		loader);
+glong		swfdec_loader_get_size		(SwfdecLoader *		loader);
 gulong		swfdec_loader_get_loaded	(SwfdecLoader *		loader);
 char *  	swfdec_loader_get_filename	(SwfdecLoader *		loader);
 SwfdecLoaderDataType
