@@ -159,7 +159,7 @@ swfdec_net_stream_video_goto (SwfdecNetStream *stream, guint timestamp)
 static void
 swfdec_net_stream_timeout (SwfdecTimeout *timeout)
 {
-  SwfdecNetStream *stream = SWFDEC_NET_STREAM ((guchar *) timeout - G_STRUCT_OFFSET (SwfdecNetStream, timeout));
+  SwfdecNetStream *stream = SWFDEC_NET_STREAM ((void *) ((guchar *) timeout - G_STRUCT_OFFSET (SwfdecNetStream, timeout)));
 
   SWFDEC_LOG ("timeout fired");
   stream->timeout.callback = NULL;
@@ -193,7 +193,7 @@ swfdec_net_stream_update_playing (SwfdecNetStream *stream)
   if (should_play && stream->timeout.callback == NULL) {
     SWFDEC_DEBUG ("starting playback");
     stream->timeout.callback = swfdec_net_stream_timeout;
-    stream->timeout.timestamp = player->time + SWFDEC_MSECS_TO_TICKS (stream->next_time - stream->current_time);
+    stream->timeout.timestamp = player->priv->time + SWFDEC_MSECS_TO_TICKS (stream->next_time - stream->current_time);
     swfdec_player_add_timeout (player, &stream->timeout);
     if (stream->flvdecoder->audio) {
       g_assert (stream->audio == NULL);
@@ -322,7 +322,7 @@ swfdec_net_stream_loader_target_init (SwfdecLoaderTargetInterface *iface)
 static void
 swfdec_net_stream_input_connect (SwfdecVideoMovieInput *input, SwfdecVideoMovie *movie)
 {
-  SwfdecNetStream *stream = SWFDEC_NET_STREAM ((guchar *) input - G_STRUCT_OFFSET (SwfdecNetStream, input));
+  SwfdecNetStream *stream = SWFDEC_NET_STREAM ((void *)((guchar *) input - G_STRUCT_OFFSET (SwfdecNetStream, input)));
 
   stream->movies = g_list_prepend (stream->movies, movie);
   g_object_ref (stream);
@@ -331,7 +331,7 @@ swfdec_net_stream_input_connect (SwfdecVideoMovieInput *input, SwfdecVideoMovie
 static void
 swfdec_net_stream_input_disconnect (SwfdecVideoMovieInput *input, SwfdecVideoMovie *movie)
 {
-  SwfdecNetStream *stream = SWFDEC_NET_STREAM ((guchar *) input - G_STRUCT_OFFSET (SwfdecNetStream, input));
+  SwfdecNetStream *stream = SWFDEC_NET_STREAM ((void *)((guchar *) input - G_STRUCT_OFFSET (SwfdecNetStream, input)));
 
   stream->movies = g_list_remove (stream->movies, movie);
   g_object_unref (stream);
@@ -340,7 +340,7 @@ swfdec_net_stream_input_disconnect (SwfdecVideoMovieInput *input, SwfdecVideoMov
 static cairo_surface_t *
 swfdec_net_stream_input_get_image (SwfdecVideoMovieInput *input)
 {
-  SwfdecNetStream *stream = SWFDEC_NET_STREAM ((guchar *) input - G_STRUCT_OFFSET (SwfdecNetStream, input));
+  SwfdecNetStream *stream = SWFDEC_NET_STREAM ((void *)((guchar *) input - G_STRUCT_OFFSET (SwfdecNetStream, input)));
 
   return stream->surface;
 }
@@ -469,11 +469,22 @@ swfdec_net_stream_new (SwfdecNetConnection *conn)
   return stream;
 }
 
+static void
+swfdec_net_stream_request_callback (SwfdecPlayer *player, SwfdecLoader *loader,
+    gpointer data)
+{
+  SwfdecNetStream *stream = data;
+
+  if (loader) {
+    swfdec_net_stream_set_loader (stream, loader);
+    g_object_unref (loader);
+  }
+}
+
 void
 swfdec_net_stream_set_url (SwfdecNetStream *stream, const char *url)
 {
   SwfdecAsContext *cx;
-  SwfdecLoader *loader;
 
   g_return_if_fail (SWFDEC_IS_NET_STREAM (stream));
   g_return_if_fail (url != NULL);
@@ -481,12 +492,9 @@ swfdec_net_stream_set_url (SwfdecNetStream *stream, const char *url)
   /* FIXME: use the connection once connections are implemented */
   cx = SWFDEC_AS_OBJECT (stream)->context;
   g_assert (cx->frame);
-  loader = swfdec_player_request_resource_now (SWFDEC_PLAYER (cx), cx->frame->security, 
-      url, SWFDEC_LOADER_REQUEST_DEFAULT, NULL);
-  if (loader) {
-    swfdec_net_stream_set_loader (stream, loader);
-    g_object_unref (loader);
-  }
+  swfdec_player_request_resource_now (SWFDEC_PLAYER (cx), cx->frame->security, 
+      url, SWFDEC_LOADER_REQUEST_DEFAULT, NULL,
+      swfdec_net_stream_request_callback, NULL, stream);
 }
 
 void
