@@ -33,6 +33,8 @@
 #include "swfdec_debug.h"
 #include "swfdec_internal.h"
 #include "swfdec_interval.h"
+#include "swfdec_as_frame_internal.h"
+
 /* FIXME: to avoid duplicate definitions */
 #undef SWFDEC_AS_NATIVE
 #define SWFDEC_AS_NATIVE(x, y, func)
@@ -83,6 +85,16 @@ swfdec_player_do_set_interval (gboolean repeat, SwfdecAsContext *cx, guint argc,
   SWFDEC_AS_VALUE_SET_INT (rval, id);
 }
 
+SWFDEC_AS_NATIVE (2, 0, swfdec_player_ASnew)
+void
+swfdec_player_ASnew (SwfdecAsContext *cx, SwfdecAsObject *obj, 
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  g_return_if_fail (cx->frame->next != NULL);
+
+  SWFDEC_AS_VALUE_SET_BOOLEAN (rval, cx->frame->next->construct);
+}
+
 SWFDEC_AS_NATIVE (250, 0, swfdec_player_setInterval)
 void
 swfdec_player_setInterval (SwfdecAsContext *cx, SwfdecAsObject *obj, 
@@ -114,12 +126,53 @@ swfdec_player_clearInterval (SwfdecAsContext *cx, SwfdecAsObject *object,
 
 /*** VARIOUS ***/
 
+SWFDEC_AS_NATIVE (100, 4, swfdec_player_trace)
+void
+swfdec_player_trace (SwfdecAsContext *cx, SwfdecAsObject *obj,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_FIXME ("Is _global.trace supposed to do something?");
+}
+
+SWFDEC_AS_NATIVE (9, 0, swfdec_player_updateAfterEvent)
+void
+swfdec_player_updateAfterEvent (SwfdecAsContext *cx, SwfdecAsObject *obj,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("updateAfterEvent");
+}
+
+SWFDEC_AS_NATIVE (1021, 1, swfdec_player_showRedrawRegions)
+void
+swfdec_player_showRedrawRegions (SwfdecAsContext *cx, SwfdecAsObject *obj,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("showRedrawRegions");
+}
+
+static void
+swfdec_player_enableDebugConsole (SwfdecAsContext *cx, SwfdecAsObject *obj,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("enableDebugConsole");
+}
+
+static void
+swfdec_player_do_nothing (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *retval)
+{
+}
+
 static SwfdecAsFunction *
 swfdec_get_asnative (SwfdecAsContext *cx, guint x, guint y)
 {
+  gboolean x_exists;
   guint i;
 
+  x_exists = FALSE;
   for (i = 0; native_funcs[i].func != NULL; i++) {
+    if (native_funcs[i].x == x)
+      x_exists = TRUE;
     if (native_funcs[i].x == x && native_funcs[i].y == y) {
       SwfdecAsFunction *fun = swfdec_as_native_function_new (cx, native_funcs[i].name,
 	  native_funcs[i].func, 0, NULL);
@@ -130,8 +183,17 @@ swfdec_get_asnative (SwfdecAsContext *cx, guint x, guint y)
       return fun;
     }
   }
-  SWFDEC_WARNING ("no AsNative (%u, %u)", x, y);
-  return NULL;
+  SWFDEC_WARNING ("no ASnative (%u, %u)", x, y);
+  if (x_exists) {
+    SwfdecAsFunction *func;
+    char *name = g_strdup_printf ("ASnative (%u, %u)", x, y);
+    func = swfdec_as_native_function_new (cx, name, swfdec_player_do_nothing,
+	0, NULL);
+    g_free (name);
+    return func;
+  } else {
+    return NULL;
+  }
 }
 
 // same as ASnative, but also sets prototype
@@ -160,8 +222,6 @@ swfdec_player_ASconstructor (SwfdecAsContext *cx, SwfdecAsObject *object,
 	&val, SWFDEC_AS_VARIABLE_HIDDEN | SWFDEC_AS_VARIABLE_PERMANENT);
 
     SWFDEC_AS_VALUE_SET_OBJECT (rval, SWFDEC_AS_OBJECT (func));
-  } else {
-    SWFDEC_FIXME ("ASconstructor for %u %u missing", x, y);
   }
 }
 
@@ -177,8 +237,6 @@ swfdec_player_ASnative (SwfdecAsContext *cx, SwfdecAsObject *object,
   func = swfdec_get_asnative (cx, x, y);
   if (func) {
     SWFDEC_AS_VALUE_SET_OBJECT (rval, SWFDEC_AS_OBJECT (func));
-  } else {
-    SWFDEC_FIXME ("ASnative for %u %u missing", x, y);
   }
 }
 
@@ -216,10 +274,8 @@ ASSetNative (SwfdecAsContext *cx, SwfdecAsObject *object,
       s++;
     }
     function = swfdec_get_asnative (cx, x, y);
-    if (function == NULL) {
-      SWFDEC_FIXME ("no ASnative function for %u, %u, what now?", x, y);
+    if (function == NULL)
       break;
-    }
     SWFDEC_AS_VALUE_SET_OBJECT (&val, SWFDEC_AS_OBJECT (function));
     swfdec_as_object_set_variable_and_flags (target,
 	swfdec_as_context_get_string (cx, s), &val, flags);
@@ -240,16 +296,8 @@ ASSetNativeAccessor (SwfdecAsContext *cx, SwfdecAsObject *object,
   char **names;
   guint i, x, y;
 
-  if (argc < 3)
-    return;
+  SWFDEC_AS_CHECK (0, NULL, "ois|i", &target, &x, &s, &y);
 
-  target = swfdec_as_value_to_object (cx, &argv[0]);
-  x = swfdec_as_value_to_integer (cx, &argv[1]);
-  s = swfdec_as_value_to_string (cx, &argv[2]);
-  if (argc > 3)
-    y = swfdec_as_value_to_integer (cx, &argv[3]);
-  else
-    y = 0;
   names = g_strsplit (s, ",", -1);
   for (i = 0; names[i]; i++) {
     s = names[i];
@@ -306,4 +354,8 @@ swfdec_player_preinit_global (SwfdecAsContext *context, guint version)
       0, swfdec_player_ASnative, 2);
   swfdec_as_object_add_function (context->global, SWFDEC_AS_STR_ASconstructor,
       0, swfdec_player_ASconstructor, 2);
+  // FIXME: is this only the debug player?
+  swfdec_as_object_add_function (context->global,
+      SWFDEC_AS_STR_enableDebugConsole, 0, swfdec_player_enableDebugConsole,
+      2);
 }
