@@ -56,13 +56,14 @@ swfdec_resource_is_root (SwfdecResource *resource)
 {
   g_return_val_if_fail (SWFDEC_IS_RESOURCE (resource), FALSE);
 
-  return resource->movie == resource->player->roots->data;
+  return
+    resource->movie == SWFDEC_FLASH_SECURITY (resource)->player->priv->roots->data;
 }
 
 static SwfdecPlayer *
 swfdec_resource_loader_target_get_player (SwfdecLoaderTarget *target)
 {
-  return SWFDEC_RESOURCE (target)->player;
+  return SWFDEC_FLASH_SECURITY (target)->player;
 }
 
 static void
@@ -93,11 +94,11 @@ swfdec_resource_loader_target_image (SwfdecResource *instance)
     movie->sprite = dec->main_sprite;
     g_assert (movie->sprite->parse_frame > 0);
     movie->n_frames = movie->sprite->n_frames;
-    swfdec_movie_invalidate (SWFDEC_MOVIE (movie));
+    swfdec_movie_invalidate_last (SWFDEC_MOVIE (movie));
     swfdec_resource_check_rights (instance);
     if (swfdec_resource_is_root (instance)) {
       swfdec_movie_initialize (SWFDEC_MOVIE (movie));
-      swfdec_player_perform_actions (instance->player);
+      swfdec_player_perform_actions (SWFDEC_FLASH_SECURITY (instance)->player);
     }
   } else {
     g_assert_not_reached ();
@@ -118,7 +119,7 @@ swfdec_resource_emit_signal (SwfdecResource *resource, const char *name, gboolea
     return;
   cx = SWFDEC_AS_OBJECT (resource->clip_loader)->context;
   g_assert (resource->target);
-  movie = swfdec_action_lookup_object (cx, SWFDEC_PLAYER (cx)->roots->data, 
+  movie = swfdec_action_lookup_object (cx, SWFDEC_PLAYER (cx)->priv->roots->data, 
       resource->target, resource->target + strlen (resource->target));
   if (!SWFDEC_IS_SPRITE_MOVIE (movie)) {
     SWFDEC_DEBUG ("no movie, not emitting signal");
@@ -200,9 +201,9 @@ swfdec_resource_create_movie (SwfdecResource *resource)
 
   if (resource->movie)
     return TRUE;
-  player = resource->player;
+  player = SWFDEC_FLASH_SECURITY (resource)->player;
   movie = (SwfdecSpriteMovie *) swfdec_action_lookup_object (SWFDEC_AS_CONTEXT (player),
-      player->roots->data, resource->target, resource->target + strlen (resource->target));
+      player->priv->roots->data, resource->target, resource->target + strlen (resource->target));
   if (!SWFDEC_IS_SPRITE_MOVIE (movie)) {
     level = swfdec_player_get_level (player, resource->target);
     if (level < 0) {
@@ -257,7 +258,8 @@ swfdec_resource_loader_target_parse (SwfdecLoaderTarget *target, SwfdecLoader *l
     if (swfdec_buffer_queue_get_depth (loader->queue) < SWFDEC_DECODER_DETECT_LENGTH)
       return;
     buffer = swfdec_buffer_queue_peek (loader->queue, 4);
-    dec = swfdec_decoder_new (resource->player, buffer);
+    dec =
+      swfdec_decoder_new (SWFDEC_FLASH_SECURITY (resource)->player, buffer);
     swfdec_buffer_unref (buffer);
     if (dec == NULL) {
       SWFDEC_ERROR ("no decoder found for format");
@@ -285,11 +287,11 @@ swfdec_resource_loader_target_parse (SwfdecLoaderTarget *target, SwfdecLoader *l
       }
       parsed += buffer->length;
       if (dec) {
-	status = swfdec_decoder_parse (dec, buffer);
+	status |= swfdec_decoder_parse (dec, buffer);
       } else {
 	swfdec_buffer_unref (buffer);
       }
-    } while ((status & (SWFDEC_STATUS_ERROR | SWFDEC_STATUS_NEEDBITS | SWFDEC_STATUS_EOF)) == 0);
+    } while (parsed < 65536 && (status & (SWFDEC_STATUS_ERROR | SWFDEC_STATUS_EOF)) == 0);
     if (status & SWFDEC_STATUS_ERROR) {
       SWFDEC_ERROR ("parsing error");
       swfdec_loader_set_target (loader, NULL);
@@ -299,8 +301,8 @@ swfdec_resource_loader_target_parse (SwfdecLoaderTarget *target, SwfdecLoader *l
       if (SWFDEC_IS_SWF_DECODER (dec))
 	resource->version = SWFDEC_SWF_DECODER (dec)->version;
       if (swfdec_resource_is_root (resource)) {
-	swfdec_player_initialize (resource->player, resource->version,
-	    dec->rate, dec->width, dec->height);
+	swfdec_player_initialize (SWFDEC_FLASH_SECURITY (resource)->player,
+	    resource->version, dec->rate, dec->width, dec->height);
       }
     }
     if (status & SWFDEC_STATUS_IMAGE)
@@ -430,7 +432,7 @@ swfdec_resource_new (SwfdecPlayer *player, SwfdecLoader *loader, const char *var
 
   resource = g_object_new (SWFDEC_TYPE_RESOURCE, NULL);
   resource->version = 7;
-  resource->player = player;
+  SWFDEC_FLASH_SECURITY (resource)->player = player;
   resource->variables = g_strdup (variables);
   swfdec_resource_set_loader (resource, loader);
 
@@ -496,7 +498,7 @@ swfdec_resource_do_unload (SwfdecPlayer *player, const char *target, gpointer re
   SwfdecSpriteMovie *movie;
   
   movie = (SwfdecSpriteMovie *) swfdec_action_lookup_object (
-      SWFDEC_AS_CONTEXT (player), player->roots->data, 
+      SWFDEC_AS_CONTEXT (player), player->priv->roots->data, 
       target, target + strlen (target));
   if (!SWFDEC_IS_SPRITE_MOVIE (movie)) {
     SWFDEC_DEBUG ("no movie, not unloading");
@@ -538,7 +540,7 @@ swfdec_resource_load (SwfdecPlayer *player, const char *target, const char *url,
   } else {
     resource = g_object_new (SWFDEC_TYPE_RESOURCE, NULL);
     resource->version = SWFDEC_AS_CONTEXT (player)->version;
-    resource->player = player;
+    SWFDEC_FLASH_SECURITY (resource)->player = player;
     resource->target = path;
     if (loader)
       resource->clip_loader = g_object_ref (loader);
@@ -556,15 +558,16 @@ swfdec_resource_emit_on_load_init (SwfdecResource *resource)
   if (resource->state != SWFDEC_RESOURCE_COMPLETE)
     return FALSE;
 
-  swfdec_resource_emit_signal (resource, SWFDEC_AS_STR_onLoadInit, FALSE, NULL, 0);
-  resource->state = SWFDEC_RESOURCE_DONE;
   if (resource->movie && SWFDEC_IS_IMAGE_DECODER (resource->decoder)) {
     SwfdecImage *image = SWFDEC_IMAGE_DECODER (resource->decoder)->image;
     if (image) {
+      swfdec_movie_invalidate_next (SWFDEC_MOVIE (resource->movie));
+      swfdec_movie_queue_update (SWFDEC_MOVIE (resource->movie), SWFDEC_MOVIE_INVALID_EXTENTS);
       SWFDEC_MOVIE (resource->movie)->image = g_object_ref (image);
-      swfdec_movie_queue_update (SWFDEC_MOVIE (resource->movie), SWFDEC_MOVIE_INVALID_CONTENTS);
     }
   }
+  swfdec_resource_emit_signal (resource, SWFDEC_AS_STR_onLoadInit, FALSE, NULL, 0);
+  resource->state = SWFDEC_RESOURCE_DONE;
   /* free now unneeded resources */
   if (resource->clip_loader) {
     g_object_unref (resource->clip_loader);
