@@ -348,6 +348,10 @@ swfdec_sound_parse_chunk (SwfdecSwfDecoder *s, SwfdecBits *b, int id)
   }
   if (has_loops) {
     chunk->loop_count = swfdec_bits_get_u16 (b);
+    if (chunk->loop_count == 0) {
+      SWFDEC_ERROR ("loop_count 0 not allowed, setting to 1");
+      chunk->loop_count = 1;
+    }
     SWFDEC_LOG ("  loop_count = %u", chunk->loop_count);
   } else {
     chunk->loop_count = 1;
@@ -368,7 +372,7 @@ swfdec_sound_parse_chunk (SwfdecSwfDecoder *s, SwfdecBits *b, int id)
     for (j = 0; j < 2; j++) {
       chunk->envelope[i].volume[j] = swfdec_bits_get_u16 (b);
       if (chunk->envelope[i].volume[j] > 32768) {
-	SWFDEC_ERROR ("envelope volume too big: %u > 32768",
+	SWFDEC_FIXME ("too big envelope volumes (%u > 32768) not handled correctly",
 	    chunk->envelope[i].volume[j]);
 	chunk->envelope[i].volume[j] = 32768;
       }
@@ -545,9 +549,9 @@ swfdec_sound_buffer_render (gint16 *dest, const SwfdecBuffer *source,
     }
   }
   if (channels == 2) {
-    swfdec_sound_buffer_render_stereo (dest, (const gint16 *) source->data, offset, n_samples, rate);
+    swfdec_sound_buffer_render_stereo (dest, (const void *) source->data, offset, n_samples, rate);
   } else {
-    swfdec_sound_buffer_render_mono (dest, (const gint16 *) source->data, offset, n_samples, rate);
+    swfdec_sound_buffer_render_mono (dest, (const void *) source->data, offset, n_samples, rate);
   }
   g_free (fixme);
 }
