@@ -229,7 +229,7 @@ swfdec_sprite_movie_perform_place (SwfdecSpriteMovie *movie, SwfdecBits *bits, g
   }
 
   if (has_name) {
-    char *s = swfdec_bits_get_string_with_version (bits, version);
+    char *s = swfdec_bits_get_string (bits, version);
     name = swfdec_as_context_give_string (SWFDEC_AS_CONTEXT (player), s);
     SWFDEC_LOG ("  name = %s", name);
   } else {
@@ -280,12 +280,10 @@ swfdec_sprite_movie_perform_place (SwfdecSpriteMovie *movie, SwfdecBits *bits, g
 	key_code = 0;
 
       SWFDEC_INFO ("clip event with flags 0x%X, key code %d", event_flags, key_code);
-#define SWFDEC_IMPLEMENTED_EVENTS \
-  ((1<< SWFDEC_EVENT_LOAD) | (1<<SWFDEC_EVENT_UNLOAD) | (1<<SWFDEC_EVENT_ENTER) | \
-   (1<< SWFDEC_EVENT_INITIALIZE) | (1<<SWFDEC_EVENT_CONSTRUCT) | \
-   (1<< SWFDEC_EVENT_MOUSE_DOWN) | (1<<SWFDEC_EVENT_MOUSE_MOVE) | (1<<SWFDEC_EVENT_MOUSE_UP))
-      if (event_flags & ~SWFDEC_IMPLEMENTED_EVENTS) {
-	SWFDEC_ERROR ("using non-implemented clip events %u", event_flags & ~SWFDEC_IMPLEMENTED_EVENTS);
+#define SWFDEC_UNIMPLEMENTED_EVENTS \
+  ((1<< SWFDEC_EVENT_DATA) | (1<<SWFDEC_EVENT_KEY_PRESS))
+      if (event_flags & SWFDEC_UNIMPLEMENTED_EVENTS) {
+	SWFDEC_ERROR ("using non-implemented clip events %u", event_flags & SWFDEC_UNIMPLEMENTED_EVENTS);
       }
       swfdec_event_list_parse (events, &action_bits, version, 
 	  event_flags, key_code, script_name);
@@ -425,7 +423,7 @@ swfdec_sprite_movie_perform_one_action (SwfdecSpriteMovie *movie, guint tag, Swf
 	  char *name;
 	  id = swfdec_bits_get_u16 (&bits);
 	  object = swfdec_swf_decoder_get_character (SWFDEC_SWF_DECODER (resource->decoder), id);
-	  name = swfdec_bits_get_string_with_version (&bits, SWFDEC_AS_CONTEXT (player)->version);
+	  name = swfdec_bits_get_string (&bits, SWFDEC_AS_CONTEXT (player)->version);
 	  if (object == NULL) {
 	    SWFDEC_ERROR ("cannot export id %u as %s, id wasn't found", id, name);
 	  } else if (name == NULL) {
@@ -518,7 +516,7 @@ swfdec_sprite_movie_goto (SwfdecSpriteMovie *movie, guint goto_frame)
   mov = SWFDEC_MOVIE (movie);
   /* lots of things where we've got nothing to do */
   if (goto_frame == 0 || goto_frame > movie->n_frames || 
-      movie->sprite == NULL || mov->will_be_removed || goto_frame == movie->frame)
+      movie->sprite == NULL || mov->state >= SWFDEC_MOVIE_STATE_REMOVED || goto_frame == movie->frame)
     return;
 
   if (goto_frame > movie->sprite->parse_frame) {
@@ -643,8 +641,8 @@ swfdec_sprite_movie_add (SwfdecAsObject *object)
 {
   SwfdecPlayer *player = SWFDEC_PLAYER (object->context);
 
-  if (player->MovieClip)
-    swfdec_as_object_set_constructor (object, player->MovieClip);
+  if (player->priv->MovieClip)
+    swfdec_as_object_set_constructor (object, player->priv->MovieClip);
 
   SWFDEC_AS_OBJECT_CLASS (swfdec_sprite_movie_parent_class)->add (object);
 }
@@ -656,7 +654,7 @@ swfdec_sprite_movie_iterate (SwfdecMovie *mov)
   SwfdecPlayer *player = SWFDEC_PLAYER (SWFDEC_AS_OBJECT (mov)->context);
   guint goto_frame;
 
-  if (mov->will_be_removed)
+  if (mov->state >= SWFDEC_MOVIE_STATE_REMOVED)
     return;
 
   if (movie->sprite && movie->frame == (guint) -1)
@@ -844,8 +842,13 @@ swfdec_sprite_movie_get_frames_loaded (SwfdecSpriteMovie *movie)
   g_return_val_if_fail (SWFDEC_IS_SPRITE_MOVIE (movie), 0);
 
   resource = swfdec_movie_get_own_resource (SWFDEC_MOVIE (movie));
-  if (resource == NULL)
-    return 1;
+  if (resource == NULL) {
+    /* FIXME: can we set n_frames to 1 for movies without sprites instead? */
+    if (movie->sprite)
+      return movie->n_frames;
+    else
+      return 1;
+  }
   dec = resource->decoder;
   if (dec == NULL)
     return -1;
@@ -863,8 +866,13 @@ swfdec_sprite_movie_get_frames_total (SwfdecSpriteMovie *movie)
   g_return_val_if_fail (SWFDEC_IS_SPRITE_MOVIE (movie), 0);
 
   resource = swfdec_movie_get_own_resource (SWFDEC_MOVIE (movie));
-  if (resource == NULL)
-    return 1;
+  if (resource == NULL) {
+    /* FIXME: can we set n_frames to 1 for movies without sprites instead? */
+    if (movie->sprite)
+      return movie->n_frames;
+    else
+      return 1;
+  }
   dec = resource->decoder;
   if (dec == NULL)
     return 0;
