@@ -35,8 +35,270 @@
 #include "swfdec_sprite_movie.h"
 #include "swfdec_swf_decoder.h"
 #include "swfdec_resource.h"
+#include "swfdec_utils.h"
 #include "swfdec_as_internal.h"
 
+SWFDEC_AS_NATIVE (900, 200, swfdec_sprite_movie_get_tabIndex)
+void
+swfdec_sprite_movie_get_tabIndex (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.tabIndex (get)");
+}
+
+SWFDEC_AS_NATIVE (900, 201, swfdec_sprite_movie_set_tabIndex)
+void
+swfdec_sprite_movie_set_tabIndex (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.tabIndex (set)");
+}
+
+SWFDEC_AS_NATIVE (900, 300, swfdec_sprite_movie_get__lockroot)
+void
+swfdec_sprite_movie_get__lockroot (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip._lockroot (get)");
+}
+
+SWFDEC_AS_NATIVE (900, 301, swfdec_sprite_movie_set__lockroot)
+void
+swfdec_sprite_movie_set__lockroot (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip._lockroot (set)");
+}
+
+SWFDEC_AS_NATIVE (900, 401, swfdec_sprite_movie_get_cacheAsBitmap)
+void
+swfdec_sprite_movie_get_cacheAsBitmap (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.cacheAsBitmap (get)");
+}
+
+SWFDEC_AS_NATIVE (900, 402, swfdec_sprite_movie_set_cacheAsBitmap)
+void
+swfdec_sprite_movie_set_cacheAsBitmap (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.cacheAsBitmap (set)");
+}
+
+SWFDEC_AS_NATIVE (900, 403, swfdec_sprite_movie_get_opaqueBackground)
+void
+swfdec_sprite_movie_get_opaqueBackground (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.opaqueBackground (get)");
+}
+
+SWFDEC_AS_NATIVE (900, 404, swfdec_sprite_movie_set_opaqueBackground)
+void
+swfdec_sprite_movie_set_opaqueBackground (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.opaqueBackground (set)");
+}
+
+SWFDEC_AS_NATIVE (900, 405, swfdec_sprite_movie_get_scrollRect)
+void
+swfdec_sprite_movie_get_scrollRect (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.scrollRect (get)");
+}
+
+SWFDEC_AS_NATIVE (900, 406, swfdec_sprite_movie_set_scrollRect)
+void
+swfdec_sprite_movie_set_scrollRect (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.scrollRect (set)");
+}
+
+SWFDEC_AS_NATIVE (900, 417, swfdec_sprite_movie_get_filters)
+void
+swfdec_sprite_movie_get_filters (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.filters (get)");
+}
+
+SWFDEC_AS_NATIVE (900, 418, swfdec_sprite_movie_set_filters)
+void
+swfdec_sprite_movie_set_filters (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.filters (set)");
+}
+
+SWFDEC_AS_NATIVE (900, 419, swfdec_sprite_movie_get_transform)
+void
+swfdec_sprite_movie_get_transform (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.transform (get)");
+}
+
+SWFDEC_AS_NATIVE (900, 420, swfdec_sprite_movie_set_transform)
+void
+swfdec_sprite_movie_set_transform (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.transform (set)");
+}
+
+static const char *blend_mode_names[] = {
+  SWFDEC_AS_STR_normal,
+  SWFDEC_AS_STR_layer,
+  SWFDEC_AS_STR_multiply,
+  SWFDEC_AS_STR_screen,
+  SWFDEC_AS_STR_lighten,
+  SWFDEC_AS_STR_darken,
+  SWFDEC_AS_STR_difference,
+  SWFDEC_AS_STR_add,
+  SWFDEC_AS_STR_subtract,
+  SWFDEC_AS_STR_invert,
+  SWFDEC_AS_STR_alpha,
+  SWFDEC_AS_STR_erase,
+  SWFDEC_AS_STR_overlay,
+  SWFDEC_AS_STR_hardlight
+};
+static const gsize num_blend_mode_names =
+  sizeof (blend_mode_names) / sizeof (blend_mode_names[0]);
+
+SWFDEC_AS_NATIVE (900, 500, swfdec_sprite_movie_get_blendMode)
+void
+swfdec_sprite_movie_get_blendMode (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SwfdecMovie *movie;
+
+  SWFDEC_AS_CHECK (SWFDEC_TYPE_MOVIE, &movie, "");
+
+  if (movie->blend_mode > 0 && movie->blend_mode <= num_blend_mode_names)
+    SWFDEC_AS_VALUE_SET_STRING (rval, blend_mode_names[movie->blend_mode - 1]);
+}
+
+SWFDEC_AS_NATIVE (900, 501, swfdec_sprite_movie_set_blendMode)
+void
+swfdec_sprite_movie_set_blendMode (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SwfdecMovie *movie;
+  SwfdecAsValue val;
+  const char *str;
+  int blend_mode;
+  gsize i;
+
+  SWFDEC_AS_CHECK (SWFDEC_TYPE_MOVIE, &movie, "v", &val);
+
+  if (SWFDEC_AS_VALUE_IS_NUMBER (&val)) {
+    blend_mode = SWFDEC_AS_VALUE_GET_NUMBER (&val);
+  } else if (SWFDEC_AS_VALUE_IS_STRING (&val)) {
+    blend_mode = 0;
+    str = SWFDEC_AS_VALUE_GET_STRING (&val);
+    for (i = 0; i < num_blend_mode_names; i++) {
+      if (str == blend_mode_names[i]) { // case-sensitive
+	blend_mode = i + 1;
+	break;
+      }
+    }
+  } else if (SWFDEC_AS_VALUE_IS_OBJECT (&val)) {
+    blend_mode = 0;
+  } else {
+    blend_mode = 1;
+  }
+
+  if ((guint)blend_mode != movie->blend_mode) {
+    movie->blend_mode = blend_mode;
+    swfdec_movie_invalidate_last (movie);
+  }
+}
+
+SWFDEC_AS_NATIVE (900, 2, swfdec_sprite_movie_localToGlobal)
+void
+swfdec_sprite_movie_localToGlobal (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.localToGlobal");
+}
+
+SWFDEC_AS_NATIVE (900, 3, swfdec_sprite_movie_globalToLocal)
+void
+swfdec_sprite_movie_globalToLocal (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.globalToLocal");
+}
+
+SWFDEC_AS_NATIVE (900, 8, swfdec_sprite_movie_attachAudio)
+void
+swfdec_sprite_movie_attachAudio (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.attachAudio");
+}
+
+SWFDEC_AS_NATIVE (900, 9, swfdec_sprite_movie_attachVideo)
+void
+swfdec_sprite_movie_attachVideo (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.attachVideo");
+}
+
+SWFDEC_AS_NATIVE (900, 23, swfdec_sprite_movie_getInstanceAtDepth)
+void
+swfdec_sprite_movie_getInstanceAtDepth (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *rval)
+{
+  SwfdecMovie *movie;
+  int depth;
+
+  SWFDEC_AS_CHECK (SWFDEC_TYPE_MOVIE, &movie, "i", &depth);
+
+  // special case
+  if (SWFDEC_AS_VALUE_IS_UNDEFINED (&argv[0]))
+    return;
+
+  movie = swfdec_movie_find (movie, depth);
+  if (movie != NULL)
+    SWFDEC_AS_VALUE_SET_OBJECT (rval, SWFDEC_AS_OBJECT (movie));
+}
+
+SWFDEC_AS_NATIVE (900, 24, swfdec_sprite_movie_getSWFVersion)
+void
+swfdec_sprite_movie_getSWFVersion (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  if (object != NULL && SWFDEC_IS_MOVIE (object)) {
+    SWFDEC_AS_VALUE_SET_INT (rval,
+	swfdec_movie_get_version (SWFDEC_MOVIE (object)));
+  } else {
+    SWFDEC_AS_VALUE_SET_INT (rval, -1);
+  }
+}
+
+SWFDEC_AS_NATIVE (900, 25, swfdec_sprite_movie_attachBitmap)
+void
+swfdec_sprite_movie_attachBitmap (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.attachBitmap");
+}
+
+SWFDEC_AS_NATIVE (900, 26, swfdec_sprite_movie_getRect)
+void
+swfdec_sprite_movie_getRect (SwfdecAsContext *cx, SwfdecAsObject *object,
+    guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SWFDEC_STUB ("MovieClip.getRect");
+}
+
 SWFDEC_AS_NATIVE (900, 12, swfdec_sprite_movie_play)
 void
 swfdec_sprite_movie_play (SwfdecAsContext *cx, SwfdecAsObject *object,
@@ -101,8 +363,8 @@ swfdec_sprite_movie_getBytesTotal (SwfdecAsContext *cx, SwfdecAsObject *object,
   }
 }
 
-// No ASnative number
-static void
+SWFDEC_AS_NATIVE (900, 22, swfdec_sprite_movie_getNextHighestDepth)
+void
 swfdec_sprite_movie_getNextHighestDepth (SwfdecAsContext *cx, SwfdecAsObject *object,
     guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
 {
@@ -237,7 +499,7 @@ swfdec_sprite_movie_hitTest (SwfdecAsContext *cx, SwfdecAsObject *object,
     swfdec_movie_global_to_local (movie, &x, &y);
 
     if (shape) {
-      ret = swfdec_movie_mouse_in (movie, x, y);
+      ret = swfdec_movie_contains (movie, x, y);
     } else {
       ret = swfdec_rect_contains (&movie->original_extents, x, y);
     }
@@ -338,9 +600,9 @@ swfdec_sprite_movie_createEmptyMovieClip (SwfdecAsContext *cx, SwfdecAsObject *o
 static void
 swfdec_sprite_movie_copy_props (SwfdecMovie *target, SwfdecMovie *src)
 {
+  swfdec_movie_queue_update (target, SWFDEC_MOVIE_INVALID_MATRIX);
   target->matrix = src->matrix;
   target->color_transform = src->color_transform;
-  swfdec_movie_queue_update (target, SWFDEC_MOVIE_INVALID_MATRIX);
 }
 
 static gboolean
@@ -371,9 +633,11 @@ swfdec_sprite_movie_init_from_object (SwfdecMovie *movie,
   if (SWFDEC_IS_SPRITE_MOVIE (movie)) {
     swfdec_movie_queue_script (movie, SWFDEC_EVENT_INITIALIZE);
     swfdec_movie_queue_script (movie, SWFDEC_EVENT_LOAD);
+    swfdec_movie_initialize (movie);
     swfdec_movie_execute (movie, SWFDEC_EVENT_CONSTRUCT);
+  } else {
+    swfdec_movie_initialize (movie);
   }
-  swfdec_movie_initialize (movie);
 }
 
 SWFDEC_AS_NATIVE (900, 0, swfdec_sprite_movie_attachMovie)
@@ -513,25 +777,68 @@ swfdec_sprite_movie_getBounds (SwfdecAsContext *cx, SwfdecAsObject *object,
   SWFDEC_AS_VALUE_SET_OBJECT (rval, obj);
 }
 
+SWFDEC_AS_NATIVE (900, 11, swfdec_sprite_movie_setMask)
+void
+swfdec_sprite_movie_setMask (SwfdecAsContext *cx, SwfdecAsObject *object,
+        guint argc, SwfdecAsValue *argv, SwfdecAsValue *rval)
+{
+  SwfdecMovie *movie, *mask;
+
+  /* yes, this works with regular movies */
+  SWFDEC_AS_CHECK (SWFDEC_TYPE_MOVIE, &movie, "O", &mask);
+
+  if (mask != NULL && !SWFDEC_IS_MOVIE (mask)) {
+    SWFDEC_FIXME ("mask is not a movie, what now?");
+    mask = NULL;
+  }
+  if (movie->masked_by)
+    movie->masked_by->mask_of = NULL;
+  if (movie->mask_of)
+    movie->mask_of->masked_by = NULL;
+  movie->masked_by = mask;
+  movie->mask_of = NULL;
+  if (movie->clip_depth) {
+    g_assert (movie->parent);
+    swfdec_movie_invalidate_last (movie->parent);
+    movie->clip_depth = 0;
+  } else {
+    swfdec_movie_invalidate_last (movie);
+  }
+  if (mask) {
+    if (mask->masked_by)
+      mask->masked_by->mask_of = NULL;
+    if (mask->mask_of)
+      mask->mask_of->masked_by = NULL;
+    mask->masked_by = NULL;
+    mask->mask_of = movie;
+    swfdec_movie_invalidate_last (mask);
+    if (mask->clip_depth) {
+      g_assert (mask->parent);
+      swfdec_movie_invalidate_last (mask->parent);
+      mask->clip_depth = 0;
+    } else {
+      swfdec_movie_invalidate_last (mask);
+    }
+  }
+}
+
 void
 swfdec_sprite_movie_init_context (SwfdecPlayer *player, guint version)
 {
+  SwfdecPlayerPrivate *priv = player->priv;
   SwfdecAsContext *context = SWFDEC_AS_CONTEXT (player);
   SwfdecAsValue val;
   SwfdecAsObject *proto;
 
-  player->MovieClip = SWFDEC_AS_OBJECT (swfdec_as_object_add_function (context->global, 
+  priv->MovieClip = SWFDEC_AS_OBJECT (swfdec_as_object_add_function (context->global, 
       SWFDEC_AS_STR_MovieClip, 0, NULL, 0));
-  if (player->MovieClip == NULL)
+  if (priv->MovieClip == NULL)
     return;
   proto = swfdec_as_object_new (context);
   if (!proto)
     return;
   SWFDEC_AS_VALUE_SET_OBJECT (&val, proto);
-  swfdec_as_object_set_variable_and_flags (player->MovieClip,
+  swfdec_as_object_set_variable_and_flags (priv->MovieClip,
       SWFDEC_AS_STR_prototype, &val, SWFDEC_AS_VARIABLE_HIDDEN |
       SWFDEC_AS_VARIABLE_PERMANENT);
-  /* now add all the functions */
-  swfdec_as_object_add_function (proto, SWFDEC_AS_STR_getNextHighestDepth, SWFDEC_TYPE_SPRITE_MOVIE, 
-      swfdec_sprite_movie_getNextHighestDepth, 0);
 };
