@@ -48,6 +48,16 @@ swfdec_text_field_movie_update_extents (SwfdecMovie *movie,
       &SWFDEC_GRAPHIC (SWFDEC_TEXT_FIELD_MOVIE (movie)->text)->extents);
 }
 
+static void
+swfdec_text_field_movie_invalidate (SwfdecMovie *movie, const cairo_matrix_t *matrix, gboolean last)
+{
+  SwfdecRect rect;
+  
+  swfdec_rect_transform (&rect, 
+    &SWFDEC_GRAPHIC (SWFDEC_TEXT_FIELD_MOVIE (movie)->text)->extents, matrix);
+  swfdec_player_invalidate (SWFDEC_PLAYER (SWFDEC_AS_OBJECT (movie)->context), &rect);
+}
+
 static void
 swfdec_text_field_movie_ensure_asterisks (SwfdecTextFieldMovie *text,
     guint length)
@@ -110,13 +120,17 @@ swfdec_text_paragraph_add_block (SwfdecParagraph *paragraph, int index_,
   block->left_margin = format->left_margin * 20;
   block->right_margin = format->right_margin * 20;
 
-  length = swfdec_as_array_get_length (format->tab_stops);
-  block->tab_stops = pango_tab_array_new (length, TRUE);
-  for (i = 0; i < length; i++) {
-    swfdec_as_array_get_value (format->tab_stops, i, &val);
-    g_assert (SWFDEC_AS_VALUE_IS_NUMBER (&val));
-    pango_tab_array_set_tab (block->tab_stops, i, PANGO_TAB_LEFT,
-	SWFDEC_AS_VALUE_GET_NUMBER (&val) * 20);
+  if (format->tab_stops != NULL) {
+    length = swfdec_as_array_get_length (format->tab_stops);
+    block->tab_stops = pango_tab_array_new (length, TRUE);
+    for (i = 0; i < length; i++) {
+      swfdec_as_array_get_value (format->tab_stops, i, &val);
+      g_assert (SWFDEC_AS_VALUE_IS_NUMBER (&val));
+      pango_tab_array_set_tab (block->tab_stops, i, PANGO_TAB_LEFT,
+	  SWFDEC_AS_VALUE_GET_NUMBER (&val) * 20);
+    }
+  } else {
+    block->tab_stops = NULL;
   }
 
   paragraph->blocks = g_slist_prepend (paragraph->blocks, block);
@@ -354,7 +368,7 @@ swfdec_text_field_movie_get_paragraphs (SwfdecTextFieldMovie *text, int *num)
   if (text->text->password)
     swfdec_text_field_movie_ensure_asterisks (text, max_length);
 
-  return (SwfdecParagraph *)g_array_free (paragraphs, FALSE);
+  return (SwfdecParagraph *) (void *) g_array_free (paragraphs, FALSE);
 }
 
 static void
@@ -368,7 +382,8 @@ swfdec_text_field_movie_free_paragraphs (SwfdecParagraph *paragraphs)
   for (i = 0; paragraphs[i].blocks != NULL; i++)
   {
     for (iter = paragraphs[i].blocks; iter != NULL; iter = iter->next) {
-      pango_tab_array_free (((SwfdecBlock *)(iter->data))->tab_stops);
+      if (((SwfdecBlock *)(iter->data))->tab_stops)
+	pango_tab_array_free (((SwfdecBlock *)(iter->data))->tab_stops);
       g_free (iter->data);
     }
     g_slist_free (paragraphs[i].blocks);
@@ -585,7 +600,8 @@ swfdec_text_field_movie_get_layouts (SwfdecTextFieldMovie *text, int *num,
 
       // set block styles
       pango_layout_set_spacing (playout, block->leading);
-      pango_layout_set_tabs (playout, block->tab_stops);
+      if (block->tab_stops != NULL)
+	pango_layout_set_tabs (playout, block->tab_stops);
 
       // set text attributes
       attr_list = swfdec_text_field_movie_paragraph_get_attr_list (
@@ -682,7 +698,7 @@ swfdec_text_field_movie_get_layouts (SwfdecTextFieldMovie *text, int *num,
   if (num != NULL)
     *num = layouts->len;
 
-  return (SwfdecLayout *)g_array_free (layouts, FALSE);
+  return (SwfdecLayout *) (void *) g_array_free (layouts, FALSE);
 }
 
 static void
@@ -717,6 +733,10 @@ swfdec_text_field_movie_render (SwfdecMovie *movie, cairo_t *cr,
   g_return_if_fail (trans != NULL);
   g_return_if_fail (inval != NULL);
 
+  /* textfields don't mask */
+  if (swfdec_color_transform_is_mask (trans))
+    return;
+
   text_movie = SWFDEC_TEXT_FIELD_MOVIE (movie);
   text = SWFDEC_TEXT_FIELD (movie->graphic);
 
@@ -724,11 +744,13 @@ swfdec_text_field_movie_render (SwfdecMovie *movie, cairo_t *cr,
 
   swfdec_rect_intersect (&limit, &movie->original_extents, inval);
 
-  cairo_rectangle (cr, limit.x0, limit.y0, limit.x1 - limit.x0, limit.y1 - limit.y0);
+  cairo_rectangle (cr, limit.x0, limit.y0, limit.x1 - limit.x0,
+      limit.y1 - limit.y0);
   cairo_clip (cr);
 
   if (text->background) {
-    cairo_rectangle (cr, limit.x0, limit.y0, limit.x1 - limit.x0, limit.y1 - limit.y0);
+    cairo_rectangle (cr, limit.x0, limit.y0, limit.x1 - limit.x0,
+	limit.y1 - limit.y0);
     color = swfdec_color_apply_transform (text_movie->background_color, trans);
     // always use full alpha
     swfdec_color_set_source (cr, color | SWFDEC_COLOR_COMBINE (0, 0, 0, 255));
@@ -736,11 +758,13 @@ swfdec_text_field_movie_render (SwfdecMovie *movie, cairo_t *cr,
   }
 
   if (text->border) {
-    cairo_rectangle (cr, movie->original_extents.x0 + SWFDEC_DOUBLE_TO_TWIPS (1),
-	movie->original_extents.y0, movie->original_extents.x1 -
-	movie->original_extents.x0 - SWFDEC_DOUBLE_TO_TWIPS (1),
-	movie->original_extents.y1 - movie->original_extents.y0 -
-	SWFDEC_DOUBLE_TO_TWIPS (1));
+    // FIXME: border should be partly outside the extents and should not be
+    // scaled, but always be 1 pixel width
+    cairo_rectangle (cr, movie->original_extents.x0 +
+	SWFDEC_DOUBLE_TO_TWIPS (1), movie->original_extents.y0,
+	movie->original_extents.x1 - movie->original_extents.x0 -
+	SWFDEC_DOUBLE_TO_TWIPS (1), movie->original_extents.y1 -
+	movie->original_extents.y0 - SWFDEC_DOUBLE_TO_TWIPS (1));
     color = swfdec_color_apply_transform (text_movie->border_color, trans);
     // always use full alpha
     swfdec_color_set_source (cr, color | SWFDEC_COLOR_COMBINE (0, 0, 0, 255));
@@ -799,8 +823,6 @@ swfdec_text_field_movie_render (SwfdecMovie *movie, cairo_t *cr,
       cairo_fill (cr);
     }
 
-    cairo_move_to (cr, x, y);
-
     skipped = 0;
     do {
       if (++linenum < MIN (text_movie->scroll, text_movie->scroll_max))
@@ -825,20 +847,18 @@ swfdec_text_field_movie_render (SwfdecMovie *movie, cairo_t *cr,
 	  x + layout->offset_x + rect.x + rect.width < limit.x0)
 	continue;
 
+      cairo_move_to (cr, x, y);
+
       if (pango_layout_iter_at_last_line (iter_line))
 	cairo_rel_move_to (cr, 0, layout->last_line_offset_y);
       cairo_rel_move_to (cr, layout->offset_x + rect.x,
 	  pango_layout_iter_get_baseline (iter_line) / PANGO_SCALE - skipped);
+
       line = pango_layout_iter_get_line_readonly (iter_line);
       pango_cairo_show_layout_line (cr, line);
-      cairo_rel_move_to (cr, -(layout->offset_x + rect.x),
-	  -(pango_layout_iter_get_baseline (iter_line) / PANGO_SCALE - skipped));
-      if (pango_layout_iter_at_last_line (iter_line))
-	cairo_rel_move_to (cr, 0, -layout->last_line_offset_y);
     } while (pango_layout_iter_next_line (iter_line));
 
     if (linenum >= MIN (text_movie->scroll, text_movie->scroll_max)) {
-      cairo_rel_move_to (cr, 0, layout->height - skipped);
       y += layout->height - skipped;
       skipped = 0;
     }
@@ -992,7 +1012,7 @@ swfdec_text_field_movie_auto_size (SwfdecTextFieldMovie *text)
       graphic->extents.y1 - graphic->extents.y0 == height)
     return FALSE;
 
-  swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+  swfdec_movie_invalidate_next (SWFDEC_MOVIE (text));
 
   if (!text->text->word_wrap && graphic->extents.x1 -
       graphic->extents.x0 != width)
@@ -1021,7 +1041,7 @@ swfdec_text_field_movie_auto_size (SwfdecTextFieldMovie *text)
   }
 
   swfdec_movie_queue_update (SWFDEC_MOVIE (text),
-      SWFDEC_MOVIE_INVALID_CONTENTS);
+      SWFDEC_MOVIE_INVALID_EXTENTS);
 
   return TRUE;
 }
@@ -1194,6 +1214,7 @@ swfdec_text_field_movie_class_init (SwfdecTextFieldMovieClass * g_class)
   movie_class->iterate_start = swfdec_text_field_movie_iterate;
   movie_class->update_extents = swfdec_text_field_movie_update_extents;
   movie_class->render = swfdec_text_field_movie_render;
+  movie_class->invalidate = swfdec_text_field_movie_invalidate;
 }
 
 static void
@@ -1526,7 +1547,7 @@ swfdec_text_field_movie_replace_text (SwfdecTextFieldMovie *text,
       end_index - start_index);
   text->input = g_string_insert (text->input, start_index, str);
 
-  swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+  swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
   swfdec_text_field_movie_auto_size (text);
   swfdec_text_field_movie_update_scroll (text, TRUE);
 }
@@ -1587,7 +1608,7 @@ swfdec_text_field_movie_set_text (SwfdecTextFieldMovie *text, const char *str,
     }
   }
 
-  swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+  swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
   swfdec_text_field_movie_auto_size (text);
   swfdec_text_field_movie_update_scroll (text, TRUE);
 }
