@@ -473,7 +473,7 @@ swfdec_text_field_movie_set_background (SwfdecAsContext *cx,
 
   if (text->text->background != value) {
     text->text->background = value;
-    swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+    swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
   }
 }
 
@@ -506,7 +506,7 @@ swfdec_text_field_movie_set_backgroundColor (SwfdecAsContext *cx,
   color = swfdec_text_field_movie_int_to_color (cx, value);
   if (text->background_color != color) {
     text->background_color = color;
-    swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+    swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
   }
 }
 
@@ -536,7 +536,7 @@ swfdec_text_field_movie_set_border (SwfdecAsContext *cx,
 
   if (text->text->border != value) {
     text->text->border = value;
-    swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+    swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
   }
 }
 
@@ -570,7 +570,7 @@ swfdec_text_field_movie_set_borderColor (SwfdecAsContext *cx,
   color = swfdec_text_field_movie_int_to_color (cx, value);
   if (text->border_color != color) {
     text->border_color = color;
-    swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+    swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
   }
 }
 
@@ -615,7 +615,7 @@ swfdec_text_field_movie_do_set_hscroll (SwfdecAsContext *cx,
   if (value != text->hscroll) {
     text->hscroll = value;
     text->scroll_changed = TRUE;
-    swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+    swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
   }
 }
 
@@ -701,7 +701,7 @@ swfdec_text_field_movie_do_set_scroll (SwfdecAsContext *cx,
     text->scroll_bottom += value - text->scroll;
     text->scroll = value;
     text->scroll_changed = TRUE;
-    swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+    swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
   }
 }
 
@@ -809,7 +809,7 @@ swfdec_text_field_movie_set_password (SwfdecAsContext *cx,
       text->asterisks = NULL;
       text->asterisks_length = 0;
     }
-    swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+    swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
   }
 }
 
@@ -839,7 +839,7 @@ swfdec_text_field_movie_set_wordWrap (SwfdecAsContext *cx,
 
   if (text->text->word_wrap != value) {
     text->text->word_wrap = value;
-    swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+    swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
     swfdec_text_field_movie_auto_size (text);
     // special case: don't set scrolling
   }
@@ -963,6 +963,96 @@ swfdec_text_field_movie_set_textColor (SwfdecAsContext *cx,
   text->format_new->color = swfdec_text_field_movie_int_to_color (cx, value);
 }
 
+SWFDEC_AS_NATIVE (104, 300, swfdec_text_field_movie_get_gridFitType)
+void
+swfdec_text_field_movie_get_gridFitType (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.gridFitType (get)");
+}
+
+SWFDEC_AS_NATIVE (104, 301, swfdec_text_field_movie_set_gridFitType)
+void
+swfdec_text_field_movie_set_gridFitType (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.gridFitType (set)");
+}
+
+SWFDEC_AS_NATIVE (104, 302, swfdec_text_field_movie_get_antiAliasType)
+void
+swfdec_text_field_movie_get_antiAliasType (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.antiAliasType (get)");
+}
+
+SWFDEC_AS_NATIVE (104, 303, swfdec_text_field_movie_set_antiAliasType)
+void
+swfdec_text_field_movie_set_antiAliasType (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.antiAliasType (set)");
+}
+
+SWFDEC_AS_NATIVE (104, 304, swfdec_text_field_movie_get_thickness)
+void
+swfdec_text_field_movie_get_thickness (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.thickness (get)");
+}
+
+SWFDEC_AS_NATIVE (104, 305, swfdec_text_field_movie_set_thickness)
+void
+swfdec_text_field_movie_set_thickness (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.thickness (set)");
+}
+
+SWFDEC_AS_NATIVE (104, 306, swfdec_text_field_movie_get_sharpness)
+void
+swfdec_text_field_movie_get_sharpness (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.sharpness (get)");
+}
+
+SWFDEC_AS_NATIVE (104, 307, swfdec_text_field_movie_set_sharpness)
+void
+swfdec_text_field_movie_set_sharpness (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.sharpness (set)");
+}
+
+SWFDEC_AS_NATIVE (104, 308, swfdec_text_field_movie_get_filters)
+void
+swfdec_text_field_movie_get_filters (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.filters (get)");
+}
+
+SWFDEC_AS_NATIVE (104, 309, swfdec_text_field_movie_set_filters)
+void
+swfdec_text_field_movie_set_filters (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.filters (set)");
+}
+
 /*
  * Native functions
  */
@@ -1050,7 +1140,7 @@ swfdec_text_field_movie_setTextFormat (SwfdecAsContext *cx,
       g_utf8_offset_to_pointer (text->input->str, end_index) -
       text->input->str);
 
-  swfdec_movie_invalidate (SWFDEC_MOVIE (text));
+  swfdec_movie_invalidate_last (SWFDEC_MOVIE (text));
   swfdec_text_field_movie_auto_size (text);
   // special case: update the max values, not the current values
   swfdec_text_field_movie_update_scroll (text, FALSE);
@@ -1100,6 +1190,15 @@ swfdec_text_field_movie_getTextFormat (SwfdecAsContext *cx,
   SWFDEC_AS_VALUE_SET_OBJECT (ret, SWFDEC_AS_OBJECT (format));
 }
 
+SWFDEC_AS_NATIVE (104, 100, swfdec_text_field_movie_replaceSel)
+void
+swfdec_text_field_movie_replaceSel (SwfdecAsContext *cx,
+    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv,
+    SwfdecAsValue *ret)
+{
+  SWFDEC_STUB ("TextField.replaceSel");
+}
+
 SWFDEC_AS_NATIVE (104, 107, swfdec_text_field_movie_replaceText)
 void
 swfdec_text_field_movie_replaceText (SwfdecAsContext *cx,
