@@ -23,7 +23,6 @@
 #include "config.h"
 #endif
 #include <stdio.h>
-#include <fcntl.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -151,6 +150,9 @@ dump_sprite (SwfdecSwfDecoder *dec, SwfdecSprite *s)
 	  /* FIXME add info about what sound etc */
 	  g_print ("   %4u start sound\n", j);
 	  break;
+	case SWFDEC_TAG_EXPORTASSETS:
+	  g_print ("   %4u export\n", j);
+	  break;
 	default:
 	  g_assert_not_reached ();
       }
@@ -283,23 +285,6 @@ dump_font (SwfdecFont *font)
 static void
 dump_button (SwfdecButton *button)
 {
-  GList *walk;
-
-#define SWFDEC_CONTENT_IN_STATE(content, state) \
-  ((content)->sequence->start <= state && \
-   (content)->sequence->end > state)
-  if (verbose) {
-    for (walk = button->records; walk; walk = walk->next) {
-      SwfdecContent *content = walk->data;
-
-      g_print ("  %s %s %s %s  %s %d\n", 
-	  SWFDEC_CONTENT_IN_STATE (content, SWFDEC_BUTTON_UP) ? "U" : " ",
-	  SWFDEC_CONTENT_IN_STATE (content, SWFDEC_BUTTON_OVER) ? "O" : " ",
-	  SWFDEC_CONTENT_IN_STATE (content, SWFDEC_BUTTON_DOWN) ? "D" : " ",
-	  SWFDEC_CONTENT_IN_STATE (content, SWFDEC_BUTTON_HIT) ? "H" : " ",
-	  G_OBJECT_TYPE_NAME (content->graphic), SWFDEC_CHARACTER (content->graphic)->id);
-    }
-  }
 }
 
 static const char *
@@ -417,8 +402,8 @@ main (int argc, char *argv[])
   }
 
   player = swfdec_player_new_from_file (argv[1]);
-  if (player->resource->loader->error) {
-    g_printerr ("Couldn't open file \"%s\": %s\n", argv[1], player->resource->loader->error);
+  if (player->priv->resource->loader->error) {
+    g_printerr ("Couldn't open file \"%s\": %s\n", argv[1], player->priv->resource->loader->error);
     g_object_unref (player);
     return 1;
   }
@@ -430,7 +415,7 @@ main (int argc, char *argv[])
     player = NULL;
     return 1;
   }
-  s = (SwfdecSwfDecoder *) SWFDEC_MOVIE (player->roots->data)->resource->decoder;
+  s = (SwfdecSwfDecoder *) SWFDEC_MOVIE (player->priv->roots->data)->resource->decoder;
   /* FIXME: can happen after a _root.loadMovie() call */
   if (!SWFDEC_IS_SWF_DECODER (s)) {
     g_printerr ("Movie already unloaded from \"%s\"\n", argv[1]);
